@@ -19,7 +19,7 @@ OC.L10N.register(
     "You have restored the board {board}" : "您恢复了面板 {board}",
     "{user} has restored the board {board}" : "{user} 恢复了 {board}",
     "You have shared the board {board} with {acl}" : "您已共享 {board} 给 {acl}",
-    "{user} has shared the board {board} with {sharee}" : "{user} 已共享面板 {board} 给 {sharee}",
+    "{user} has shared the board {board} with {acl}" : "{user} 已使用 {acl} 共享面板 {board}",
     "You have removed {acl} from the board {board}" : "您从面板 {board} 中移除了 {acl}",
     "{user} has removed {acl} from the board {board}" : "{user} 从面板 {board} 中移除了 {acl} ",
     "You have renamed the board {before} to {board}" : "您将面板 {before} 重命名为 {board}",
@@ -77,6 +77,7 @@ OC.L10N.register(
     "A <strong>card description</strong> inside the Deck app has been changed" : "看板应用中的 <strong>卡片描述</strong> 已改变",
     "Deck" : "看板",
     "Changes in the <strong>Deck app</strong>" : "<strong>看板应用</strong>中的改变",
+    "A <strong>comment</strong> was created on a card" : "卡片上创建了一个 <strong>评论</strong>",
     "Personal" : "个人",
     "The card \"%s\" on \"%s\" has been assigned to you by %s." : "%s已给您指派\"%s\" 中的卡片\"%s\"。",
     "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} 已给您指派\"%s\" 中的卡片\"%s\"。",
